@@ -45,6 +45,14 @@ sub tmpfile_with_name
     return $name;
 }
 
+sub all_passes
+{
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
+    my ( $in, $out, $opt ) = @_;
+    return generic( "1-9", $in, $out, $opt );
+}
+
 sub generic
 {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -73,6 +81,14 @@ sub add_files
     push @files_to_del, @_;
 }
 
+sub new_tempdir
+{
+    my $old = cwd()->absolute();
+    my $ret = Path::Tiny->tempdir();
+    chdir($ret);
+    return { orig => $old, new => $ret, };
+}
+
 sub cleanup
 {
     foreach my $fn (@files_to_del)
